summaryrefslogtreecommitdiffstats
path: root/kalzium/src/kalziumtip.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kalzium/src/kalziumtip.cpp')
-rw-r--r--kalzium/src/kalziumtip.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kalzium/src/kalziumtip.cpp b/kalzium/src/kalziumtip.cpp
index e0e05388..671b1759 100644
--- a/kalzium/src/kalziumtip.cpp
+++ b/kalzium/src/kalziumtip.cpp
@@ -38,7 +38,7 @@
#include <klocale.h>
#include <kstandarddirs.h>
-KalziumTip::KalziumTip( TQWidget * tqparent, const char * name, WFlags f ) : TQWidget( tqparent, name, f )
+KalziumTip::KalziumTip( TQWidget * parent, const char * name, WFlags f ) : TQWidget( parent, name, f )
{
setFocusPolicy(TQ_NoFocus); //the widget don't get the keyboard focus
setBackgroundMode(NoBackground); // widget has no background
@@ -54,8 +54,8 @@ KalziumTip::KalziumTip( TQWidget * tqparent, const char * name, WFlags f ) : TQW
void KalziumTip::showTip( TQPoint mouse, Element* element, int visibleWidth, int visibleHeight )
{
TQWidget *p = 0;
- if ( dynamic_cast<TQWidget*>( tqparent() ) )
- p = TQT_TQWIDGET( tqparent() );
+ if ( dynamic_cast<TQWidget*>( parent() ) )
+ p = TQT_TQWIDGET( parent() );
if ( p )
{
@@ -113,7 +113,7 @@ void KalziumTip::paintEvent(TQPaintEvent* e)
void KalziumTip::mouseMoveEvent(TQMouseEvent * e)
{
// delegate the mouse move event to the tqparent (actually the elements table)
// so that this tooltip doesn't stop to be updated
e->ignore();
}
@@ -172,12 +172,12 @@ void KalziumTip::displayInternal()
int width = textX + textRect.width() + margin;
int textY = (height - textRect.height()) / 2;
- //resize pixmap, tqmask and widget
- m_tqmask.resize(width, height);
+ //resize pixmap, mask and widget
+ m_mask.resize(width, height);
m_pixmap.resize(width, height);
resize(width, height);
- // create and set transparency tqmask
+ // create and set transparency mask
switch(m_maskEffect)
{
case Plain:
@@ -218,14 +218,14 @@ void KalziumTip::displayInternal()
void KalziumTip::dissolveMask()
{
- TQPainter maskPainter(&m_tqmask);
+ TQPainter maskPainter(&m_mask);
- m_tqmask.fill(TQt::black);
+ m_mask.fill(TQt::black);
maskPainter.setBrush(TQt::white);
maskPainter.setPen(TQt::white);
- maskPainter.drawRoundRect(m_tqmask.rect(), 1600 / m_tqmask.rect().width(),
- 1600 / m_tqmask.rect().height());
+ maskPainter.drawRoundRect(m_mask.rect(), 1600 / m_mask.rect().width(),
+ 1600 / m_mask.rect().height());
m_dissolveSize += m_dissolveDelta;
@@ -257,7 +257,7 @@ void KalziumTip::dissolveMask()
m_dissolveDelta = 1;
}
- setMask(m_tqmask);
+ setMask(m_mask);
}
void KalziumTip::hide()
@@ -269,15 +269,15 @@ void KalziumTip::hide()
void KalziumTip::plainMask()
{
- TQPainter maskPainter(&m_tqmask);
+ TQPainter maskPainter(&m_mask);
- m_tqmask.fill(TQt::black);
+ m_mask.fill(TQt::black);
maskPainter.setBrush(TQt::white);
maskPainter.setPen(TQt::white);
- maskPainter.drawRoundRect(m_tqmask.rect(), 1600 / m_tqmask.rect().width(),
- 1600 / m_tqmask.rect().height());
- setMask(m_tqmask);
+ maskPainter.drawRoundRect(m_mask.rect(), 1600 / m_mask.rect().width(),
+ 1600 / m_mask.rect().height());
+ setMask(m_mask);
m_frameTimer.stop();
}
@@ -113,7 +113,7 @@ void KalziumTip::paintEvent(TQPaintEvent* e)
void KalziumTip::mouseMoveEvent(TQMouseEvent * e)
{
- // delegate the mouse move event to the tqparent (actually the elements table)
+ // delegate the mouse move event to the parent (actually the elements table)
// so that this tooltip doesn't stop to be updated
e->ignore();